==> kxdocker_0.26.orig.tar.gz: kxdocker-0.26.orig/src/xeroot.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Stefano                                         *
 *   stefano@xiaprojects.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "xeroot.h"

XERoot::XERoot(QObject *parent, const char *name)
 : XEObject(parent, name)
{
	xEngineRoot=this;
}


XERoot::~XERoot()
{
}


#include "xeroot.moc"


/*!
    \fn XERoot::xSetup()
 */
void XERoot::xSetup()
{
	QPtrListIterator<QObject> it(xPlugins);
	QObject *xPlugin;
	while ( (xPlugin = it.current()) != 0 ) {
		++it;
		connect(this,
			SIGNAL(xPluginSetup()),
			xPlugin,
			SLOT(xSetup())
			);
			
		connect(this,
			SIGNAL(xPluginStart()),
			xPlugin,
			SLOT(xStart())
			);
			
	}
	xPluginSetup();
}


/*!
    \fn XERoot::xStart()
 */
void XERoot::xStart()
{
	xPluginStart();
}


/*!
    \fn XERoot::xStop()
 */
void XERoot::xStop()
{
    /// @todo implement me
}

==> kxdocker_0.35.orig.tar.gz: kxdocker-0.35.orig/src/xeroot.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Stefano                                         *
 *   stefano@xiaprojects.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "xeroot.h"

XERoot::XERoot(QObject *parent, const char *name)
 : XEObject(parent, name)
{
	xEngineRoot=this;
}


XERoot::~XERoot()
{
}


#include "xeroot.moc"


/*!
    \fn XERoot::xSetup()
 */
void XERoot::xSetup()
{
	QPtrListIterator<QObject> it(xPlugins);
	QObject *xPlugin;
	while ( (xPlugin = it.current()) != 0 ) {
		++it;
		connect(this,
			SIGNAL(xPluginSetup()),
			xPlugin,
			SLOT(xSetup())
			);
			
		connect(this,
			SIGNAL(xPluginStart()),
			xPlugin,
			SLOT(xStart())
			);
		connect(this,
			SIGNAL(xPluginStop()),
			xPlugin,
			SLOT(xStop())
			);
			
	}
	xPluginSetup();
}


/*!
    \fn XERoot::xStart()
 */
void XERoot::xStart()
{
	xPluginStart();
}


/*!
    \fn XERoot::xStop()
 */
void XERoot::xStop()
{
	//qWarning("void XERoot::xStop()");
	xPluginStop();
}
